/* *************************************************************************** */
/*                This do.file replicates the paper:                           */
/*			      "Poverty and crime in 19th century Germany"                  */
/*			      by Halvor Mehlum, Edward Miguel & Ragnar Torvik              */
/*			      published in Journal of Urban Economics, 2006                */
/* *************************************************************************** */


/* *************************************************************************** */
/* *********************    -FIRST STEPS-    ********************************* */
/* *************************************************************************** */

/*Install commands used in analysis*/
capture log close
capture ssc install outreg2
capture net from http://www.stata.com/users/bpoi/

#delimit ;
clear;
set more off;
cap program drop _all;
cap log close;

/* Set memory as needed*/
set mem 60m;

/* Change line within quotes below to reflect local working directory */;
	global REPDIR "C:\Users\ecascardi\Desktop\Final Germany";

cd "$REPDIR";

log using germanylog, text replace ;


/* *************************************************************************** */
/* *********************    -DATA MANIPULATION-    *************************** */
/* *************************************************************************** */

/* IMPORTING DATASET */

insheet using bavaria_data.csv;
   // see Codebook file for variable names and labels;
   
/* WORKING WITH VARIABLES/MACROS */;

	/* Palantine */;
	gen mv3 = real(mv_p);
	/* gen cr3 = real(cr_p); */;

	foreach var in mv cr vi	to mu
	{;
	/* The Kingdom - overall average */;
	gen `var'0 = real(`var'_tk);

	/* Upper Bavaria */;
	gen `var'1 = real(`var'_ub);

	/* Lower Bavaria */;
	gen `var'2 = real(`var'_lb);

	/* Upper Palantine */;
	gen `var'4 = real(`var'_up);

	/* Upper Franconia */;
	gen `var'5 = real(`var'_uf);

	/* Central Franconia */;
	gen `var'6 = real(`var'_cf);

	/* Lower Franconia */;
	gen `var'7 = real(`var'_lf);

	/* Schwabia */;
	gen `var'8 = real(`var'_s);
	};

	/* Set the correct prices by region */;
	gen pr3 = real(prp);

	gen pr0 = real(prcr);
	gen pr1 = real(prcr);
	gen pr2 = real(prcr);
	gen pr4 = real(prcr);
	gen pr5 = real(prcr);
	gen pr6 = real(prcr);
	gen pr7 = real(prcr);
	gen pr8 = real(prcr);

	/* Lagged rain */;
	sort year;
	gen rain_1 = rain[_n-1];
	gen rain_2 = rain[_n-2];
	gen rwage1  = rwage[_n+1];
	gen rain1 = rain[_n+1];

	/* Set time series term */;
	tsset year;

	reshape long mv cr pr vi mu to, i(year) j(prov);

	gen pr_1  = pr[_n-1];

	/* Logs*/;
	gen lpr = log(pr);
	gen lpr_1 = log(pr_1);
	gen lw = log(rwage);
	gen lw1 = log(rwage1);
	gen lpb = log(prb);
	gen lcr = log(cr);
	gen lmv = log(mv);
	gen lvi = log(vi);
	gen lto = log(to);
	gen lmu = log(mu);
	gen lcr_1 = lcr[_n-1];

	gen tr2 = tr^2;
	gen tr3 = tr^3;

	gen tr_rev = tr*rev;
	gen tr2_rev = tr2*rev;
	gen tr3_rev = tr3*rev;

	gen tr_rain = tr*rain;
	gen tr_rain_1 = tr*rain_1;
	gen tr_rain_2 = tr*rain_2;
	gen tr_lpr = tr*lpr;
	gen tr_pr = tr*pr;
	gen tr_lw = tr*lw;
	gen tr_rwage = tr*rwage;

	global time = "tr rev tr_rev";
	global time2 = "tr tr2 rev tr_rev tr2_rev";
	global time3 = "tr tr2 tr3 rev tr_rev tr2_rev tr3_rev";

	/* Halvor District Fixed Effects*/;
	gen pro1=0;
	replace pro1 = 1 if prov==1;
	gen pro2=0;
	replace pro2 = 1 if prov==2;
	gen pro3=0;
	replace pro3 = 1 if prov==3;
	gen pro4=0;
	replace pro4 = 1 if prov==4;
	gen pro5=0;
	replace pro5 = 1 if prov==5;
	gen pro6=0;
	replace pro6 = 1 if prov==6;
	gen pro7=0;
	replace pro7 = 1 if prov==7;
	gen pro8=0;
	replace pro8 = 1 if prov==8;
	global prdum = "pro2 pro4 pro5 pro6 pro7 pro8";


	gen non_sample = 0;
	replace non_sample=1 if 
		(pr==. | cr==. | rain==. | rain_1==. | rain_2==. | year==. );

	gen panel_sample = 1;
	replace panel_sample=0 if 
		(pr==. | cr==. | rain==. | rain_1==. | rain_2==. | year==. | prov == 0  );

	gen bav_sample = 1;
	replace bav_sample=0 if 
		(pr==. | cr==. | rain==. | rain_1==. | rain_2==. | year==. | real(cr_tk)==. | prov!=0  );
		
	gen testt = 0;
	replace testt =1 if (non_sample==0 & prov==1);

	gen all_bav = 0;
	replace all_bav = 1 if prov==1;

/* RELABLING VARIABLES (as in the paper) */

	label variable cr "Property crime (annual, per 100,000 population)";
	label variable lcr "Ln(Property crime)";
	label variable vi "Violent crime (annual, per 100,000 population)";
	label variable lvi "Ln(Violent crime)";
	label variable mu "Murders (annual, per 100,000 population)";
	label variable lmu "Ln(Murders)";
	label variable to "Total crime (annual, per 100,000 population)";
	label variable lto "Ln(Total crime)";
	label variable mv "Begging, vagrancy arrests (annual, per 100,000 population)";
	label variable lmv "Ln(Begging, vagrancy arrests)";
	label variable pr "Rye prices (Florins per bushel)";
	label variable lpr "Ln(Rye prices)";
	label variable rwage1 "Real wage (1910 = 100)";
	label variable lw1 "Ln(Real wage)";
	label variable rain "Rainfall, year t";
	label variable rain_1 "Rainfall, year t-1";
	label variable rain_2 "Rainfall, year t-2";
	label variable tr "Time trend";
	label variable tr2 "(Time trend)^2";
	label variable rev "Post-1847";
	label variable tr_rev "Time trend*Post-1847";
	label variable tr2_rev "(Time trend)^2*Post-1847";
		

/* EXPORTING DATASET */;
	
	* .dta;
save f_bavaria, replace;
	* .csv;
//outsheet f_bavaria.csv, replace comma

/* *************************************************************************** */
/* *********************    -TABLES-    ************************************** */
/* *************************************************************************** */

/* TABLE 1: DESCRIPTIVE STATISTICS */
  
	estpost sum if bav_sample;
	outreg2 if bav_sample using Table_1_A.doc, replace sum(log) dec(2) eqdrop(max min) title("Table 1", "Descriptive statistics, All Bavaria") keep(cr lcr vi lvi mu lmu to lto mv lmv pr lpr rwage1 lw1 rain rain_1 rain_2)  sortvar(cr lcr vi lvi mu lmu to lto mv lmv pr lpr rwage1 lw1 rain rain_1 rain_2) label;
	estpost sum if panel_sample;
	outreg2 if panel_sample using Table_1_B.doc, replace sum(log) dec(2) eqdrop(max min) title("Table 1", "Descriptive statistics, Bavarian states") keep(cr lcr vi lvi mu lmu to lto mv lmv pr lpr rwage1 lw1 rain rain_1 rain_2) sortvar(cr lcr vi lvi mu lmu to lto mv lmv pr lpr rwage1 lw1 rain rain_1 rain_2) label;
					
	sort all_bav;

/* TABLE 2: FIRST STAGE & REDUCED FORM RESULTS */;

	/* Regression Estimates & Generating Output of TABLE 2 */;
	    /* Combined due to problems in outreg storing F-stat in macros */;
	
	regress lpr rain rain_1 rain_2 if bav_sample, robust;
	dwstat;
	test rain rain_1 rain_2;
	return list;
	outreg2 using Table_2_A.doc, replace title("Table 2.A", "First-stage and reduced-form results") ctitle("ln(Rye", "price)", "OLS") stats(coef se) dec(2) stnum(replace coef=coef*1000, replace se=se*1000) paren(se) aster(coef) addstat(Root MSE, e(rmse), F stat, r(F)) nocons label;
	
	regress lpr rain rain_1 rain_2 tr tr2 rev tr_rev tr2_rev if bav_sample, robust cluster(year);
	dwstat;
	test rain rain_1 rain_2;
	return list;
	outreg2 using Table_2_A.doc, append title("Table 2.A", "First-stage and reduced-form results") ctitle("ln(Rye", "price)", "OLS") stats(coef se) dec(2) stnum(replace coef=coef*1000, replace se=se*1000) paren(se) aster(coef) addstat(Root MSE, e(rmse), F stat, r(F)) nocons label;
	
	regress lpr rain rain_1 rain_2 tr tr2 rev tr_rev tr2_rev `$prdum' if panel_sample, robust cluster(year);
	dwstat;
	test rain rain_1 rain_2;
	return list;
	outreg2 using Table_2_A.doc, append title("Table 2.A", "First-stage and reduced-form results") ctitle("ln(Rye", "price)", "OLS") stats(coef se) dec(2) stnum(replace coef=coef*1000, replace se=se*1000) paren(se) aster(coef) addstat(Root MSE, e(rmse), F stat, r(F)) nocons label;

	regress lw1 rain rain_1 rain_2 tr tr2 rev tr_rev tr2_rev `$prdum' if bav_sample, robust cluster(year);
	dwstat;
	test rain rain_1 rain_2;
	return list;
	outreg2 using Table_2_B.doc, replace  title("Table 2.B", "First-stage and reduced-form results") ctitle("ln(Real", "wage)", "OLS") stats(coef se) dec(2) stnum(replace coef=coef*1000, replace se=se*1000) paren(se) aster(coef) addstat("Root MSE", e(rmse), F stat, r(F)) nocons label;
	
	regress lcr rain rain_1 rain_2 tr tr2 rev tr_rev tr2_rev `$prdum' if bav_sample, robust cluster(year);
	dwstat;
	test rain rain_1 rain_2;
	return list;
	outreg2 using Table_2_B.doc, append  title("Table 2.B", "First-stage and reduced-form results") ctitle("ln(Property", "crime)", "OLS") stats(coef se) dec(2) stnum(replace coef=coef*1000, replace se=se*1000) paren(se) aster(coef) addstat("Root MSE", e(rmse), F stat, r(F)) nocons label;
	
	regress lvi rain rain_1 rain_2 tr tr2 rev tr_rev tr2_rev `$prdum' if bav_sample, robust cluster(year);
	dwstat;
	test rain rain_1 rain_2;
	return list;
	outreg2 using Table_2_B.doc, append  title("Table 2.B", "First-stage and reduced-form results") ctitle("ln(Violent", "crime)", "OLS") stats(coef se) dec(2) stnum(replace coef=coef*1000, replace se=se*1000) paren(se) aster(coef) addstat("Root MSE", e(rmse), F stat, r(F)) nocons  label;

/* TABLE 3: SECOND STAGE/ IV - Poverty and property crimes */;

	/* Regression Estimates */;
	
		/* ALL BAVARIA */;
		regress lcr lpr if bav_sample, robust;
		dwstat;
		estimates store n1;

		/* ALL BAVARIA */;
		regress lcr lpr $time2 if bav_sample, robust;
		dwstat;
		estimates store n2;

		/* ALL BAVARIA - IV */;
		regress lcr lpr $time2 (rain rain_1 rain_2 $time2) if bav_sample, robust;
		dwstat;
		estimates store n3;

		/* BY PROVINCE - IV */;
		regress lcr lpr  $prdum $time2 (rain rain_1 rain_2 $time2 $prdum ) if panel_sample, robust cluster(year);
		dwstat;
		estimates store n4;

		/* ALL BAVARIA */;
		regress lcr lw1 if bav_sample, robust;
		dwstat;
		estimates store n5;

		/* ALL BAVARIA */;
		regress lcr lw1 $time2 if bav_sample, robust;
		dwstat;
		estimates store n6;

		/* ALL BAVARIA - IV */;
		regress lcr lw1 $time2 (rain rain_1 rain_2 $time2) if bav_sample, robust;
		dwstat;
		estimates store n7;

		/* BY PROVINCE */;
		regress lcr lw1  $prdum $time2 (rain rain_1 rain_2 $time2 $prdum ) if panel_sample, robust cluster(year);
		dwstat;
		estimates store n8;

		/* TRY MOREIRA LIML ESTIMATOR */;
		condivreg lcr (lpr = rain rain_1 rain_2) if bav_sample, liml;
		estimates store n3b;

		/* BEST SPEC */;
		condivreg lcr $time2 (lpr = rain rain_1 rain_2) if bav_sample, liml;
		estimates store n3c;

		/* TRY MOREIRA LIML ESTIMATOR */;
		condivreg lcr (lw1 = rain rain_1 rain_2) if bav_sample, liml;
		estimates store n7b;
		/* BEST SPEC */;
		condivreg lcr $time2 (lw1 = rain rain_1 rain_2) if bav_sample, liml;
		estimates store n7c;

	/* Generating Output of Table 3 */;

	outreg2 [n1] using Table_3_A.doc, replace title("Table 3.A", "Poverty and property crimes") ctitle("ln(Property", "crime)", "OLS") keep(lcr lpr) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, No, District fixed effects, No) nocons label;
	outreg2 [n2] using Table_3_A.doc, append title("Table 3.A", "Poverty and property crimes") ctitle("ln(Property", "crime)", "OLS") keep(lcr lpr) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, Yes, District fixed effects, No) nocons label;
	outreg2 [n3] using Table_3_A.doc, append  title("Table 3.A", "Poverty and property crimes") ctitle("ln(Property", "crime)", "IV-2SLS") keep(lcr lpr) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, Yes, District fixed effects, No) nocons label;
	outreg2 [n4] using Table_3_A.doc, append  title("Table 3.A", "Poverty and property crimes") ctitle("ln(Property", "crime)", "IV-2SLS") keep(lcr lpr) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, Yes, District fixed effects, Yes) nocons label;
	outreg2 [n5] using Table_3_B.doc, replace  title("Table 3.B", "Poverty and property crimes") ctitle("ln(Property", "crime)", "OLS") keep(lcr lw1) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, No, District fixed effects, No) nocons label;
	outreg2 [n6] using Table_3_B.doc, append  title("Table 3.B", "Poverty and property crimes") ctitle("ln(Property", "crime)", "OLS") keep(lcr lw1) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, Yes, District fixed effects, No) nocons label;
	outreg2 [n7] using Table_3_B.doc, append  title("Table 3.B", "Poverty and property crimes") ctitle("ln(Property", "crime)", "IV-2SLS") keep(lcr lw1) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, Yes, District fixed effects, No) nocons label;
	outreg2 [n8] using Table_3_B.doc, append  title("Table 3.B", "Poverty and property crimes") ctitle("ln(Property", "crime)", "IV-2SLS") keep(lcr lw1) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, Yes, District fixed effects, Yes) nocons label;

/* TABLE 4 : SECOND STAGE / IV - Poverty and major crime categories */;

	/* Regression Estimates */;
	
	regress lmv lpr $time2 (rain rain_1 rain_2 $time2) if bav_sample, robust;
	dwstat if e(sample);
	estimates store p1;

	regress lcr lpr $time2 (rain rain_1 rain_2 $time2) if bav_sample, robust;
	dwstat if e(sample);
	estimates store p2;

	regress lvi lpr $time2 (rain rain_1 rain_2 $time2) if bav_sample, robust;
	dwstat if e(sample);
	estimates store p3;

	regress lmu lpr $time2 (rain rain_1 rain_2 $time2) if bav_sample, robust;
	dwstat if e(sample);
	estimates store p4;

	regress lto lpr $time2 (rain rain_1 rain_2 $time2) if bav_sample, robust;
	dwstat if e(sample);
	estimates store p5;

	/* Generating Output of Table 4 */;

	outreg2 [p1] using Table_4.doc, replace title("Table 4", "Poverty and major crime categories") ctitle("Ln(Begging", "vagrancy)", "IV-2SLS") drop($time2) dec(2) stats(coef se) paren(se) aster(coef) addtext(Time controls, Yes) addstat(Root MSE, e(rmse)) nocons label;
	outreg2 [p2] using Table_4.doc, append  title("Table 4", "Poverty and major crime categories") ctitle("ln(Property", "crime)", "IV-2SLS") drop($time2) dec(2) stats(coef se) paren(se) aster(coef) addtext(Time controls, Yes) addstat(Root MSE, e(rmse)) nocons label;
	outreg2 [p3] using Table_4.doc, append  title("Table 4", "Poverty and major crime categories") ctitle("ln(Violent", "crime)", "IV-2SLS") drop($time2) dec(2) stats(coef se) paren(se) aster(coef) addtext(Time controls, Yes) addstat(Root MSE, e(rmse)) nocons label;
	outreg2 [p4] using Table_4.doc, append  title("Table 4", "Poverty and major crime categories") ctitle("ln(Murder)", "IV-2SLS") drop($time2) dec(2) stats(coef se) paren(se) aster(coef) addtext(Time controls, Yes) addstat(Root MSE, e(rmse)) nocons label;
	outreg2 [p5] using Table_4.doc, append  title("Table 4", "Poverty and major crime categories") ctitle("ln(Total", "crime)", "IV-2SLS") drop($time2) dec(2) stats(coef se) paren(se) aster(coef) addtext(Time controls, Yes) addstat(Root MSE, e(rmse)) nocons label;

/* TABLE 5 : Poverty and violent crimes and murder */;

	/* Regression Estimates */;
	
	* Ln(Violent Crime);
		/* BY PROVINCE */;
		regress lvi lpr $time2 if bav_sample, robust;
		dwstat;
		estimates store q1;
		/* BY PROVINCE */;
		regress lvi lpr $time2 (rain rain_1 rain_2 $time2) if bav_sample, robust;
		dwstat;
		estimates store q2;
		/* ALL BAVARIA */;
		regress lvi lpr $prdum $time2 (rain rain_1 rain_2 $time2 $prdum) if panel_sample, robust cluster(year);
		dwstat;
		estimates store q3;

	* Ln(Murder);
		/* BY PROVINCE */;
		regress lmu lpr $time2 if bav_sample, robust;
		dwstat ;
		estimates store q4;
		/* BY PROVINCE */;
		regress lmu lpr $time2 (rain rain_1 rain_2 $time2) if bav_sample, robust;
		dwstat;
		estimates store q5;
		/* ALL BAVARIA */;
		regress lmu lpr $prdum $time2 (rain rain_1 rain_2 $time2 $prdum) if panel_sample, robust cluster(year);
		dwstat;
		estimates store q6;

	/* Generating Output of Table 5 */;

	outreg2 [q1] using Table_5_A.doc, replace title("Table 5.A", "Poverty and violent crimes and murder") ctitle("ln(Violent", "crime)", "OLS") drop($time2 $prdum) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, Yes, District fixed effects, No) nocons label;
	outreg2 [q2] using Table_5_A.doc, append  title("Table 5.A", "Poverty and violent crimes and murder") ctitle("ln(Violent", "crime)", "IV-2SLS") drop($time2 $prdum) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, Yes, District fixed effects, No) nocons label;
	outreg2 [q3] using Table_5_A.doc, append  title("Table 5.A", "Poverty and violent crimes and murder") ctitle("ln(Violent", "crime)", "IV-2SLS") drop($time2 $prdum) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, Yes, District fixed effects, Yes) nocons label;
	outreg2 [q4] using Table_5_B.doc, replace title("Table 5.B", "Poverty and violent crimes and murder") ctitle("ln(Murder)", "OLS") drop($time2 $prdum) dec(2) stats(coef se) paren(se) aster(coef) nocons addstat(Root MSE, e(rmse)) addtext(Time controls, Yes, District fixed effects, No) label;
	outreg2 [q5] using Table_5_B.doc, append  title("Table 5.B", "Poverty and violent crimes and murder") ctitle("ln(Murder)", "IV-2SLS") drop($time2 $prdum) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, Yes, District fixed effects, No) nocons label;
	outreg2 [q6] using Table_5_B.doc, append  title("Table 5.B", "Poverty and violent crimes and murder") ctitle("ln(Murder)", "IV-2SLS") drop($time2 $prdum) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, Yes, District fixed effects, Yes) nocons label;
	
/* TABLE A.1 APPENDIX : Poverty and property crimesusing only lagged rainfall as instruments */;

	/* Regression Estimates */;
	
		/* ALL BAVARIA */;
		regress lcr lpr $time2 if bav_sample, robust;
		dwstat;
		estimates store r1;
		/* ALL BAVARIA - IV */;
		regress lcr lpr $time2 (rain_1 rain_2 $time2) if bav_sample, robust;
		dwstat;
		estimates store r2;
		
		/* BY PROVINCE - IV */;
		regress lcr lpr  $prdum $time2 (rain_1 rain_2 $time2 $prdum ) if panel_sample, robust cluster(year);
		dwstat;
		estimates store r3;

		/* ALL BAVARIA */;
		regress lcr lw1 $time2 if bav_sample, robust;
		dwstat;
		estimates store r4;

		/* ALL BAVARIA - IV */;
		regress lcr lw1 $time2 (rain_1 rain_2 $time2) if bav_sample, robust;
		dwstat;
		estimates store r5;

		/* BY PROVINCE */;
		regress lcr lw1  $prdum $time2 (rain_1 rain_2 $time2 $prdum ) if panel_sample, robust cluster(year);
		dwstat;
		estimates store r6;

	/* Generating Output of Table A.1 */;

	outreg2 [r1] using Table_Append_A.doc, replace title("Appendix Table A.1.A", "Poverty and property crimesusing only lagged rainfall as instruments") ctitle("ln(Property", "crime)", "OLS") keep(lcr lpr) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, Yes, District fixed effects, No) nocons label;
	outreg2 [r2] using Table_Append_A.doc, append  title("Appendix Table A.1.A", "Poverty and property crimesusing only lagged rainfall as instruments") ctitle("ln(Property", "crime)", "IV-2SLS") keep(lcr lpr) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, Yes, District fixed effects, No) nocons label;
	outreg2 [r3] using Table_Append_A.doc, append  title("Appendix Table A.1.A", "Poverty and property crimesusing only lagged rainfall as instruments") ctitle("ln(Property", "crime)", "IV-2SLS") keep(lcr lpr) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, Yes, District fixed effects, Yes) nocons label;
	outreg2 [r4] using Table_Append_B.doc, replace  title("Appendix Table A.1.B", "Poverty and property crimesusing only lagged rainfall as instruments") ctitle("ln(Property", "crime)", "OLS") keep(lcr lw1) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, Yes, District fixed effects, No) nocons label;
	outreg2 [r5] using Table_Append_B.doc, append  title("Appendix Table A.1.B", "Poverty and property crimesusing only lagged rainfall as instruments") ctitle("ln(Property", "crime)", "IV-2SLS") keep(lcr lw1) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, Yes, District fixed effects, No) nocons label;
	outreg2 [r6] using Table_Append_B.doc, append  title("Appendix Table A.1.B", "Poverty and property crimesusing only lagged rainfall as instruments") ctitle("ln(Property", "crime)", "IV-2SLS") keep(lcr lw1) dec(2) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) addtext(Time controls, Yes, District fixed effects, Yes) nocons label;

/* *************************************************************************** */
/* *********************    -GRAPHS-    ************************************** */
/* *************************************************************************** */

/* For all figures in the paper see figures.xlsx file in the replication folder */;


/* *************************************************************************** */
/* ************    -RESULTS NOT SHOWN IN PUBLISHED TABLES-    **************** */
/* *************************************************************************** */
	
/* See "Results Not Shown" do.file */;
	
/* *************************************************************************** */
/* *********************    -LAST STEPS-    ********************************** */
/* *************************************************************************** */

clear
log close
